@@ -1,7 +1,7 @@
 /*
   SPDX-FileCopyrightText: 2024-2025 Laurent Montel <montel@kde.org>
 
-  SPDX-License-Identifier: GPL-2.0-only
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "activitiesmanagertest.h"
@@ -15,7 +15,7 @@ ActivitiesManagerTest::ActivitiesManagerTest(QObject *parent)
 
 void ActivitiesManagerTest::shouldHaveDefaultValues()
 {
-    ActivitiesManager w;
+    const ActivitiesManager w;
     QVERIFY(!w.enabled());
     QVERIFY(w.accountActivities());
 }
