@@ -6,6 +6,7 @@
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
+// clazy:excludeall=overloaded-signal
 
 #pragma once
 
@@ -139,7 +140,7 @@ public:
 
     virtual void showConfigurationDialog(QWidget *parent);
 
-    QByteArray identifier() const;
+    QByteArray &identifier();
     virtual void setIdentifier(const QByteArray &identifier);
 
     /**
@@ -178,10 +179,6 @@ public:
     virtual void setDateRange(const QDateTime &start, const QDateTime &end, const QDate &preferredMonth = QDate());
 
     QDateTime startDateTime() const;
-    QDateTime endDateTime() const;
-
-    QDateTime actualStartDateTime() const;
-    QDateTime actualEndDateTime() const;
 
     /** Returns true if the view supports navigation through the date navigator
         ( selecting a date range, changing month, changing year, etc. )
