@@ -15,12 +15,6 @@
 #include <KLocalizedString>
 #include <KMessageBox>
 
-QColor KOHelper::getTextColor(const QColor &c)
-{
-    const double luminance = (c.red() * 0.299) + (c.green() * 0.587) + (c.blue() * 0.114);
-    return (luminance > 128.0) ? QColor(0, 0, 0) : QColor(255, 255, 255);
-}
-
 QColor KOHelper::resourceColor(const Akonadi::Collection &coll)
 {
     return EventViews::resourceColor(coll, KOPrefs::instance()->eventViewsPreferences());
@@ -37,17 +31,7 @@ void KOHelper::setResourceColor(const Akonadi::Collection &collection, const QCo
     KOPrefs::instance()->eventViewsPreferences()->writeConfig();
 }
 
-int KOHelper::yearDiff(QDate start, QDate end)
-{
-    return end.year() - start.year();
-}
-
 bool KOHelper::isStandardCalendar(Akonadi::Collection::Id id)
 {
     return id == CalendarSupport::KCalPrefs::instance()->defaultCalendarId();
 }
-
-void KOHelper::showSaveIncidenceErrorMsg(QWidget *parent, const KCalendarCore::Incidence::Ptr &incidence)
-{
-    KMessageBox::error(parent, i18n("Unable to save %1 \"%2\".", i18n(incidence->typeStr().constData()), incidence->summary()));
-}
