@@ -25,11 +25,13 @@ public:
     KOTodoView(bool sidebarView, QWidget *parent);
     ~KOTodoView() override;
 
-    void setCalendar(const Akonadi::ETMCalendar::Ptr &) override;
+    void setModel(QAbstractItemModel *model) override;
+    void calendarAdded(const Akonadi::CollectionCalendar::Ptr &calendar) override;
+    void calendarRemoved(const Akonadi::CollectionCalendar::Ptr &calendar) override;
 
-    Q_REQUIRED_RESULT Akonadi::Item::List selectedIncidences() override;
-    Q_REQUIRED_RESULT KCalendarCore::DateList selectedIncidenceDates() override;
-    Q_REQUIRED_RESULT int currentDateCount() const override
+    [[nodiscard]] Akonadi::Item::List selectedIncidences() override;
+    [[nodiscard]] KCalendarCore::DateList selectedIncidenceDates() override;
+    [[nodiscard]] int currentDateCount() const override
     {
         return 0;
     }
@@ -44,17 +46,17 @@ public:
     /** documentation in baseview.h */
     void getHighlightMode(bool &highlightEvents, bool &highlightTodos, bool &highlightJournals) override;
 
-    Q_REQUIRED_RESULT bool usesFullWindow() override;
+    [[nodiscard]] bool usesFullWindow() override;
 
     void saveViewState();
     void restoreViewState();
 
-    Q_REQUIRED_RESULT bool supportsDateRangeSelection() override
+    [[nodiscard]] bool supportsDateRangeSelection() override
     {
         return false;
     }
 
-    Q_REQUIRED_RESULT CalendarSupport::CalPrinterBase::PrintType printType() const override;
+    [[nodiscard]] CalendarSupport::CalPrinterBase::PrintType printType() const override;
 
 public Q_SLOTS:
     void setIncidenceChanger(Akonadi::IncidenceChanger *changer) override;
