@@ -10,6 +10,7 @@
 #include "kdatenavigator.h"
 #include "kodaymatrix.h"
 #include "koglobals.h"
+#include "prefs/koprefs.h"
 #include "widgets/navigatorbar.h"
 
 #include <KLocalizedString>
@@ -38,7 +39,7 @@ KDateNavigator::KDateNavigator(QWidget *parent)
     connect(mNavigatorBar, &NavigatorBar::monthSelected, this, &KDateNavigator::monthSelected);
     connect(mNavigatorBar, &NavigatorBar::yearSelected, this, &KDateNavigator::yearSelected);
 
-    QString generalFont = QFontDatabase::systemFont(QFontDatabase::GeneralFont).family();
+    QString const generalFont = QFontDatabase::systemFont(QFontDatabase::GeneralFont).family();
 
     // Set up the heading fields.
     for (int i = 0; i < 7; ++i) {
@@ -58,6 +59,7 @@ KDateNavigator::KDateNavigator(QWidget *parent)
 
         topLayout->addWidget(mWeeknos[i], i + 2, 0);
     }
+    mWeeknosWidth = mWeeknos[0]->width(); // save an initial width for the weekno buttons
 
     mDayMatrix = new KODayMatrix(this);
     mDayMatrix->setObjectName(QLatin1StringView("KDateNavigator::dayMatrix"));
@@ -152,32 +154,31 @@ void KDateNavigator::setHighlightMode(bool highlightEvents, bool highlightTodos,
 
 void KDateNavigator::updateDates()
 {
-    QDate dayone = startDate();
+    QDate const dayone = startDate();
 
     mDayMatrix->updateView(dayone);
 
     // set the week numbers.
     for (int i = 0; i < 6; ++i) {
         // Use QDate's weekNumber method to determine the week number!
-        QDate dtStart = mDayMatrix->getDate(i * 7);
-        QDate dtEnd = mDayMatrix->getDate((i + 1) * 7 - 1);
+        QDate const dtStart = mDayMatrix->getDate(i * 7);
+        QDate const dtEnd = mDayMatrix->getDate((i + 1) * 7 - 1);
         const int weeknumstart = dtStart.weekNumber();
         const int weeknumend = dtEnd.weekNumber();
         QString weeknum;
 
         if (weeknumstart != weeknumend) {
-            weeknum = i18nc("start/end week number of line in date picker", "%1/%2", weeknumstart, weeknumend);
+            weeknum = i18nc("@info start/end week number of line in date picker", "%1/%2", weeknumstart, weeknumend);
         } else {
             weeknum.setNum(weeknumstart);
         }
         mWeeknos[i]->setText(weeknum);
         mWeeknos[i]->setToolTip(i18nc("@info:tooltip", "Scroll to week number %1", weeknum));
-        mWeeknos[i]->setWhatsThis(
-            i18n("Click here to scroll the display to week number %1 "
-                 "of the currently displayed year.",
-                 weeknum));
+        mWeeknos[i]->setWhatsThis(i18nc("@info:whatsthis",
+                                        "Click here to scroll the display to week number %1 "
+                                        "of the currently displayed year.",
+                                        weeknum));
     }
-
     // each updateDates is followed by an updateView -> repaint is issued there !
     //  mDayMatrix->repaint();
 }
@@ -205,6 +206,20 @@ QDate KDateNavigator::month() const
     }
 }
 
+void KDateNavigator::setShowWeekNums(bool enabled)
+{
+    if (!enabled) {
+        mWeeknosWidth = mWeeknos[0]->width();
+    }
+    for (int i = 0; i < 6; ++i) {
+        if (enabled) {
+            mWeeknos[i]->setMaximumWidth(mWeeknosWidth);
+        } else {
+            mWeeknos[i]->setFixedWidth(0);
+        }
+    }
+}
+
 void KDateNavigator::updateView()
 {
     updateDayMatrix();
@@ -213,36 +228,24 @@ void KDateNavigator::updateView()
 
 void KDateNavigator::updateConfig()
 {
-    int weekstart = KOGlobals::self()->firstDayOfWeek();
+    int const weekstart = KOGlobals::self()->firstDayOfWeek();
+    setShowWeekNums(KOPrefs::instance()->mWeekNumbersShow);
     for (int i = 0; i < 7; ++i) {
         const int day = weekstart + i <= 7 ? weekstart + i : (weekstart + i) % 7;
-        QString dayName = QLocale().dayName(day, QLocale::ShortFormat);
-        QString longDayName = QLocale().dayName(day, QLocale::LongFormat);
+        QString const dayName = QLocale().dayName(day, QLocale::ShortFormat);
+        QString const longDayName = QLocale().dayName(day, QLocale::LongFormat);
         mHeadings[i]->setText(dayName);
         mHeadings[i]->setToolTip(i18nc("@info:tooltip", "%1", longDayName));
-        mHeadings[i]->setWhatsThis(i18n("A column header of the %1 dates in the month.", longDayName));
+        mHeadings[i]->setWhatsThis(i18nc("@info:whatsthis", "A column header of the %1 dates in the month.", longDayName));
     }
     mDayMatrix->setUpdateNeeded();
     updateDayMatrix();
     update();
-    // FIXME: Use actual config setting here
-    //  setShowWeekNums( true );
-}
-
-void KDateNavigator::setShowWeekNums(bool enabled)
-{
-    for (int i = 0; i < 6; ++i) {
-        if (enabled) {
-            mWeeknos[i]->show();
-        } else {
-            mWeeknos[i]->hide();
-        }
-    }
 }
 
 void KDateNavigator::selectMonthHelper(int monthDifference)
 {
-    QDate baseDateNextMonth = mBaseDate.addMonths(monthDifference);
+    QDate const baseDateNextMonth = mBaseDate.addMonths(monthDifference);
 
     KCalendarCore::DateList newSelection = mSelectedDates;
     for (int i = 0; i < mSelectedDates.count(); ++i) {
